This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Patch installed for comments in builtins.c


Minor comment cleanup before various forthcoming patches in this area.
We use a mix of logN and log* in various comments, this makes us
consistently use logN.


Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/ChangeLog,v
retrieving revision 2.3068
diff -u -p -r2.3068 ChangeLog
--- ChangeLog	6 Mar 2004 01:21:16 -0000	2.3068
+++ ChangeLog	6 Mar 2004 03:19:06 -0000
@@ -1,3 +1,7 @@
+2004-03-05  Kaveh R. Ghazi  <ghazi@caip.rutgers.edu>
+
+	* builtins.c: Consistently use logN not log* in comments.
+
 2004-03-05  Andreas Krebbel  <krebbel1@de.ibm.com>
 
 	* rtl.h (mem_expr_equal_p): Function prototype added.
Index: builtins.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/builtins.c,v
retrieving revision 1.288
diff -u -p -r1.288 builtins.c
--- builtins.c	2 Mar 2004 22:32:25 -0000	1.288
+++ builtins.c	6 Mar 2004 03:19:06 -0000
@@ -6172,8 +6172,8 @@ real_dconstp (tree expr, const REAL_VALU
 }
 
 /* A subroutine of fold_builtin to fold the various logarithmic
-   functions.  EXP is the CALL_EXPR of a call to a builtin log*
-   function.  VALUE is the base of the log* function.  */
+   functions.  EXP is the CALL_EXPR of a call to a builtin logN
+   function.  VALUE is the base of the logN function.  */
 
 static tree
 fold_builtin_logarithm (tree exp, const REAL_VALUE_TYPE *value)
@@ -6187,7 +6187,7 @@ fold_builtin_logarithm (tree exp, const 
       tree arg = TREE_VALUE (arglist);
       const enum built_in_function fcode = builtin_mathfn_code (arg);
 	
-      /* Optimize log*(1.0) = 0.0.  */
+      /* Optimize logN(1.0) = 0.0.  */
       if (real_onep (arg))
 	return build_real (type, dconst0);
 
@@ -6218,7 +6218,7 @@ fold_builtin_logarithm (tree exp, const 
 		      || fcode == BUILT_IN_EXP10L))))
 	return convert (type, TREE_VALUE (TREE_OPERAND (arg, 1)));
 
       /* Optimize log*(func()) for various exponential functions.  We
          want to determine the value "x" and the power "exponent" in
          order to transform logN(x**exponent) into exponent*logN(x).  */
       if (flag_unsafe_math_optimizations)
@@ -6218,7 +6218,7 @@ fold_builtin_logarithm (tree exp, const 
 	return convert (type, TREE_VALUE (TREE_OPERAND (arg, 1)));
 
-      /* Optimize log*(func()) for various exponential functions.  We
+      /* Optimize logN(func()) for various exponential functions.  We
          want to determine the value "x" and the power "exponent" in
          order to transform logN(x**exponent) into exponent*logN(x).  */


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]